netapp_ontap.models.cluster_nodes_controller_frus API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_controller_frus`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesControllerFrusSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesControllerFrus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `id: str GET`

    The id field of the cluster_nodes_controller_frus.

  `state: str GET`

    The state field of the cluster_nodes_controller_frus.

    Valid choices:

    - ok
    - error
  `type: str GET`

    The type field of the cluster_nodes_controller_frus.

    Valid choices:

    - fan
    - psu
    - pcie
    - disk
    - nvs
    - dimm
    - controller